<h3>
  <code>{{ job.load.fun }}</code>
  {% if job.user %}<small class="text-muted">by {{ job.user }}</small>{% endif %}
</h3>
<h6>Targets: <small class="text-muted">{{ job.targets|join:", " }}</small> </h6>


<h6>Args: {% if not job.load.arg %}<span class="text-muted">[]</span>{% endif %}</h6>
{% if job.args or job.kwargs %}
  <ul>
    {% for arg in job.args %}
      <li><code>{{ arg }}</code></li>
    {% endfor %}
    {% for k, v in job.kwargs.items %}
      <li><code>{{ k }}={{ v }}</code></li>
    {% endfor %}
  </ul>
{% endif %}
